Status class

Constructors

Status(String text, Color? bgColor, Color? textColor, BorderRadius? radius)
const

Properties

bgColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
radius BorderRadius?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
textColor Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited